yakumo.neutron.v2.lb.member

Package yakumo :: Package neutron :: Package v2 :: Package lb :: Module member |
[hide private]
[frames] | no frames]

# Module member

source code

Resource class and its manager for LB backend members in Networking V2 API

Classes | [hide private]
| Resource Resource class for LB backend members in Networking V2 API
| Manager Manager class for LB backend members in Networking V2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.neutron.v2.lb``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('project', 'tenant_id', mapper.Resource('
      project')), ('pool', 'pool_id', mapper.Resource('neutron.lb.pool')), (
      'is_enabled', 'admin_state_up', mapper.Noop), ('protocol_port', 'proto
      col_port', mapper.Noop), ('weight', 'weight', mapper.Noop), ('status',
       'status', mapper.Noop), ('address', 'address', mapper.Noop),]